/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kyuubi.server.ui

import org.apache.kyuubi.{KyuubiException, KyuubiFunSuite}

class JettyUtilsSuite extends KyuubiFunSuite {

  test("create static resource handler") {
    val contextPath = "/dist"
    val handler = JettyUtils.createStaticHandler("dist", contextPath)
    assert(handler.getContextPath === contextPath)
    val e = intercept[KyuubiException](JettyUtils
      .createStaticHandler("nonexists", contextPath))
    assert(e.getMessage.startsWith("Could not find resource path"))
  }
}
